Struct TexEnv

pub struct TexEnv { /* private fields */ }
A texture combiner, also called a “texture environment” (hence the struct name). See also texenv.h documentation.

Implementations

Source

impl TexEnv

pub fn as_raw(&self) -> *mut C3D_TexEnv

pub fn new() -> TexEnv

Create a new texture combiner stage, or “texture environment”

pub fn reset(self) -> TexEnv

pub fn src( self, mode: Mode, source0: Source, source1: Option<Source>, source2: Option<Source>, ) -> TexEnv

Set the sources to use for the rgb and/or alpha components of this texenv stage. If sourcing from a texture unit, ensure a texture is also bound to that unit with [Frame::with_texture]

pub fn op_rgb(self, o1: RGBOp, o2: Option<RGBOp>, o3: Option<RGBOp>) -> TexEnv

pub fn op_alpha( self, o1: AlphaOp, o2: Option<AlphaOp>, o3: Option<AlphaOp>, ) -> TexEnv

pub fn func(self, mode: Mode, func: CombineFunc) -> TexEnv

pub fn color(self, color: u32) -> TexEnv

pub fn scale(self, mode: Mode, scale: Scale) -> TexEnv